/************************************************************************
 *
 * lomac_rta.c
 *
 * LOMAC - Low Water-Mark Mandatory Access Control for Linux 
 * Copyright (C) 1999 NAI Labs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License as published by the Free Software Foundation.  This program
 * is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.  You should have received a copy of the
 * GNU General Public License along with this program; if not, write
 * to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 *
 *
 * This file contains the implementation of some useful RunTime
 * Assertion (RTA) utility functions.
 *
 ************************************************************************/

#include "kernel_kernel.h"

#include "lomac_rta.h"

/* is_malformed_absolute_path()
 *
 * in:     potentially bad pointer to a potentially bad string
 * out:    nothing 
 * return: 0 if `path_s' is a well-formed absolute pathname in a 
 *         well-formed null-terminated string, otherwise 1.
 */

int is_malformed_absolute_path( const char *path_s ) {

  int index;

  if( !path_s ) {
    return( 1 );
  }

  if( path_s[ 0 ] != '/' ) {  /* absolute paths only, please. */
    return( 1 );
  }

  for( index = 1; index <= L_MAX_PATH_LENGTH; index++ ) {
    if( path_s[ index ] == '\0' ) {
      return( 0 );
    }
    if( path_s[ index ] & 0x80 ) { /* 8th bit should be clean for ASCII */
      return( 1 );
    }
  }
  
  return( 1 );

} /* is_malformed_absolute_path() */
